@@ -3,15 +3,21 @@
  * Pleasanton Ca. 94588 USA
  * E-MAIL dbs@tanj.com
  *
- * You may freely copy, use, and distribute this software,
- * in whole or in part, subject to the following restrictions:
+ */
+
+/*
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, either version 3 of the License, or
+ *   (at your option) any later version.
  *
- *  1)  You may not charge money for it.
- *  2)  You may not remove or alter this copyright notice.
- *  3)  You may not claim you wrote it.
- *  4)  If you make improvements (or other changes), you are requested
- *      to send them to me, so there's a focal point for distributing
- *      improved versions.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -25,58 +31,6 @@
 extern unsigned char cm11map[];
 extern unsigned char map2cm11[];
 
-char *funcmap[] = {
-        "All Off",
-	"All On",
-	"On",
-	"Off",
-	"Dim",
-	"Bright",
-	"All Lights Off",
-	"Extended Code",
-	"Hail Request",
-	"Hail Acknowledge",
-	"Pre Set Dim %5",
-	"Pre Set Dim %75",
-	"Extended Data Transfer",
-	"Status is On",
-	"Status is Off",
-	"Status Request" } ;
-
-
-/* This function returns an integer between 1 and 16.
- * It expects hex_unit to be the hex number coresponding to a
- * unit number.
- * Return -1 upon failure to find a match.
- */
-
-int unit2int(hex_unit)
-int hex_unit;
-{
-
-  char RCSID[]= "@(#) $Id: cm11a.c,v 1.7 1999/12/13 19:30:26 dbs Exp dbs $\n";
-
-  int unhexed;
-  display(RCSID);
-
-  /* Unit numbers may be 1 to 16.  Enforce this restriction */
-  hex_unit &= 0x0F;
-
-  /* search through the external array 'cm11map'
-   * Return the index that matches the value
-   */
-
-  unhexed = 0;
-  while ( unhexed < 16 )
-  {
-      if( hex_unit == cm11map[unhexed++] )
-          break;
-  }
-  if( unhexed == 16  && hex_unit != cm11map[15]  )
-      unhexed = -1;
-
-  return(unhexed);
-}
 
 /* This function will transform a 16 bit bitmap of devices in X10 format,
  * IE bit 6 is device 1 to a human readable map where bit 0 is device 1.
