@@ -2,26 +2,34 @@
  * Changes for use with CM11A copyright 1996, 1997 Daniel B. Suthers,
  * Pleasanton Ca, 94588 USA
  * E-mail dbs@tanj.com
- * Same permissions and restrictions as below.
+ *
  */
 /*
  * Copyright 1986 by Larry Campbell, 73 Concord Street, Maynard MA 01754 USA
- * (maynard!campbell).  You may freely copy, use, and distribute this software
- * subject to the following restrictions:
- *
- *  1)	You may not charge money for it.
- *  2)	You may not remove or alter this copyright notice.
- *  3)	You may not claim you wrote it.
- *  4)	If you make improvements (or other changes), you are requested
- *	to send them to me, so there's a focal point for distributing
- *	improved versions.
+ * (maynard!campbell).
  *
  * John Chmielewski (tesla!jlc until 9/1/86, then rogue!jlc) assisted
  * by doing the System V port and adding some nice features.  Thanks!
  */
 
 /*
- * BSR X-10 "Powerhouse" Computer Interface Definitions
+ *   This program is free software: you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation, either version 3 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+/*
+ * X-10 CM11 Computer Interface Definitions
  */
 
 /***********************************************************************/
@@ -29,35 +37,54 @@
 /* your system                                                         */
 /***********************************************************************/
 
-/* Some lints don't know about the void type */
-
 #ifndef _x10_header
 #define _x10_header
 
+/* Some lints don't know about the void type */
+#include "local.h"
+
 #ifdef VOID
 #define void int
 #endif
 
+#ifdef  SCO
+#define _IBCS2
+#endif  
 
+#if 0
 #ifndef XDIR
 #define XDIR "."		/* directory containing X10 files */
 #endif
+#endif
 
+/* directory for spool file */
 #ifndef SPOOLDIR
-#define SPOOLDIR "/var/tmp/" /* dir for spool files */
+#define SPOOLDIR "/var/tmp/heyu"
 #endif
 
 /* directory used for locks, specified in the Filesystem Hierarchy Standard */
 #ifndef LOCKDIR
-#ifdef SOLARIS
-#define LOCKDIR "/var/spool/locks"
-#else
 #define LOCKDIR "/var/lock"
-#endif
+#endif 
+
+/* Base directory under user $HOME */
+#define HOMEBASEDIR           ".heyu/" 
+
+/* system-wide Heyu base directory */
+#ifndef SYSBASEDIR
+#define SYSBASEDIR "/etc/heyu"
 #endif
 
+#define SPOOLFILE  "heyu.out"
+#define RELAYFILE  "heyu.relay"
+#define WRITEFILE  "heyu.write"
+#define AUXFILE    "heyu.aux"
+#define LOGFILE    "heyu.log"
+
+#if 0
 #define IDFILE "/x10id"		/* description file for X10 modules */
 #define ALIASFILE "/.x10config"	/* description file for X10 modules */
+#endif
 
 #ifdef  MINIEXCH		/* if talking through a DEC Mini-Exchange */
 #define MINIXPORT 3		/* port number X10 gizmo is plugged in to */
@@ -70,21 +97,34 @@
 #endif
 
 #define TIMEOUT 10		/* seconds to wait for data */
+#if 0
 #define DTIMEOUT 15		/* timeout for dim and diagnostic commands */
+#endif
 
 /***********************************************************************/
 /*                  End of configuration section                       */
 /***********************************************************************/
 
+/* Bitmaps for bits 0-3 of the CM11a send status block - (per CWS) */
+#define  RESERVED_STATUS_BIT      8
+#define  PURGE_DELAYED_MACROS     4
+#define  RESET_BATTERY_TIMER      2
+#define  MONITORED_STATUS_CLEAR   1
 
+#if 0
 #define SYNCN 16		/* number of FF chars to send before packet */
 
 #define CHKSUM(buf) chksum(buf, sizeof(buf))
+#endif
 
 #define DIM 0x4
 #define BRIGHT 0x5
+#define EXTCODE 0x7
 #define EXTEND 0xC
+#define PRESET1 0xA
+#define PRESET2 0xB
 
+#if 0
 /* Event item as stored in event file */
 
 struct evitem
@@ -168,6 +208,7 @@ struct nstruct
     char *n_name;
     char n_code;
     };
+#endif
 
 /* Message definitions */
 
